
# Slot: positively regulates, entity to entity




URI: [biolink:positively_regulates_entity_to_entity](https://w3id.org/biolink/vocab/positively_regulates_entity_to_entity)

## Domain and Range

[MolecularEntity](MolecularEntity.md) ->  <sub>0..*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [regulates, entity to entity](regulates_entity_to_entity.md)

## Children


## Used by

 * [MolecularEntity](MolecularEntity.md)
